@@ -10,7 +10,7 @@ use Exporter 'import';
 our @EXPORT_OK = qw/ifdef $ifdef/;
 
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 
 sub ifdef(&$) {
@@ -27,7 +27,11 @@ our $ifdef = sub {
 
     return undef if not defined $obj;
 
-    return $obj->$method(@args)   if blessed $obj or reftype $method eq 'CODE';
+    return $obj->$method(@args)   if blessed $obj;
+    
+    my $methtype = reftype($method);
+    return $obj->$method(@args)   if defined($methtype) and $methtype eq 'CODE';
+    
     return $obj->[$method]        if reftype $obj eq 'ARRAY';
     return $obj->{$method}        if reftype $obj eq 'HASH';
     return $obj->($method, @args) if reftype $obj eq 'CODE';
@@ -51,7 +55,7 @@ Scalar::IfDefined
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
